==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ScalerParamsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScalerParamsDescription } from "./ScalerParamsDescription";
/**
 * @hidden
 */
var ScalerParamsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScalerParamsDescriptionMetadata, _super);
    function ScalerParamsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScalerParamsDescriptionMetadata.b = function (a) {
        if (ScalerParamsDescriptionMetadata.a == null) {
            ScalerParamsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScalerParamsDescriptionMetadata.c(ScalerParamsDescriptionMetadata.a);
        }
        if (a.g(ScalerParamsDescriptionMetadata.a)) {
            return;
        }
        a.s(ScalerParamsDescriptionMetadata.a);
    };
    ScalerParamsDescriptionMetadata.c = function (a) {
        a.item("ReferenceValue", "Number:double");
    };
    ScalerParamsDescriptionMetadata.d = function (a) {
        ScalerParamsDescriptionMetadata.b(a);
        a.u("ScalerParams", function () { return new ScalerParamsDescription(); });
        a.t("ScalerParams", ScalerParamsDescriptionMetadata.a);
    };
    ScalerParamsDescriptionMetadata.$t = markType(ScalerParamsDescriptionMetadata, 'ScalerParamsDescriptionMetadata');
    ScalerParamsDescriptionMetadata.a = null;
    return ScalerParamsDescriptionMetadata;
}(Base));
export { ScalerParamsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScalerParamsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScalerParamsDescription } from "./ScalerParamsDescription";
/**
 * @hidden
 */
var ScalerParamsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScalerParamsDescriptionMetadata, _super);
    function ScalerParamsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScalerParamsDescriptionMetadata.b = function (a) {
        if (ScalerParamsDescriptionMetadata.a == null) {
            ScalerParamsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScalerParamsDescriptionMetadata.c(ScalerParamsDescriptionMetadata.a);
        }
        if (a.j(ScalerParamsDescriptionMetadata.a)) {
            return;
        }
        a.y(ScalerParamsDescriptionMetadata.a);
    };
    ScalerParamsDescriptionMetadata.c = function (a) {
        a.item("ReferenceValue", "Number:double");
    };
    ScalerParamsDescriptionMetadata.d = function (a) {
        ScalerParamsDescriptionMetadata.b(a);
        a.aa("ScalerParams", function () { return new ScalerParamsDescription(); });
        a.z("ScalerParams", ScalerParamsDescriptionMetadata.a);
    };
    ScalerParamsDescriptionMetadata.$t = markType(ScalerParamsDescriptionMetadata, 'ScalerParamsDescriptionMetadata');
    ScalerParamsDescriptionMetadata.a = null;
    return ScalerParamsDescriptionMetadata;
}(Base));
export { ScalerParamsDescriptionMetadata };
